﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Text;
using System.Windows.Forms;

using INT_PT002.DataStore;
using SmartX;

namespace INT_PT002.Forms
{
    public partial class FormMain : Form
    {
        #region Field
        public bool IsCommunicationLogOpen;
        public int DecimalPlaces3;
        public int DecimalPlaces4;
        private int CommunicationCheckCount;

        // 파일 위치
        private string m_PathLaunchFolder;
        private string m_PathSystemFileFolder;
        private string m_PathDataBackupFolder;

        // 장비 구동 상태
        private Define.E_EquipmentStatus m_EquipmentStatus;

        // SystemConfiguration
        public SystemConfiguration SystemConfig;

        // Leak Data
        private Collection<LeakData> CollectionLeakDatas;

        public FormMainDisplay1 ChildFormMainDisplay;
        public FormMenu ChildFormMenu;
        #endregion

        #region Constructor
        public FormMain()
        {
            InitializeComponent();
        } 
        #endregion

        #region Property
        public string PathLaunchFolder
        {
            get { return this.m_PathLaunchFolder; }
            set { this.m_PathLaunchFolder = value; }
        }
        public string PathSystemFileFolder
        {
            get { return this.m_PathSystemFileFolder; }
            set { this.m_PathSystemFileFolder = value; }
        }
        public string PathDataBackupFolder
        {
            get { return this.m_PathDataBackupFolder; }
            set { this.m_PathDataBackupFolder = value; }
        }

        public Define.E_EquipmentStatus EquipmentStatus
        {
            get { return this.m_EquipmentStatus; }
            private set { this.m_EquipmentStatus = value; }
        }
        #endregion

        #region Method
        private void DefaultSetting()
        {
            this.IsCommunicationLogOpen = false;
            this.DecimalPlaces3 = 3;
            this.DecimalPlaces4 = 4;
            this.CommunicationCheckCount = 0;

            this.EquipmentStatus = Define.E_EquipmentStatus.Stop;

            this.PathLaunchFolder = "SD Card\\";
            this.PathSystemFileFolder = this.PathLaunchFolder + "SystemFile\\";
            this.PathDataBackupFolder = this.PathLaunchFolder + "DataBackup\\";

            this.SystemConfig = new SystemConfiguration();

            this.CollectionLeakDatas = new Collection<LeakData>();
            for (int i = 0; i < 10; i++)
                this.CollectionLeakDatas.Add(new LeakData());

            // SystemFile 폴더 생성
            if (Directory.Exists(this.PathSystemFileFolder) == false)
                Directory.CreateDirectory(this.PathSystemFileFolder);

            // DataBackup 폴더 생성
            if (Directory.Exists(this.PathDataBackupFolder) == false)
                Directory.CreateDirectory(this.PathDataBackupFolder);
        }
        private void CreateForm()
        {
            this.ChildFormMainDisplay = new FormMainDisplay1(this);
            this.ChildFormMenu = new FormMenu(this);

            this.smartForm1.MainForm = this;

            this.smartForm1.AddChildForm(this.ChildFormMainDisplay);
            this.smartForm1.AddChildForm(this.ChildFormMenu);
        }
        private void TransferSystemParameter()
        {
            StringBuilder sb = new StringBuilder();

            sb.Append(Helper.StringZeroFillDigits6(this.SystemConfig.OverRange));
            sb.Append(Helper.StringZeroFillDigits4(this.SystemConfig.VacuumStartTime.ToString()));
            sb.Append(Helper.StringZeroFillDigits4(this.SystemConfig.VacuumHoldTime.ToString()));
            sb.Append(Helper.StringZeroFillDigits4(this.SystemConfig.VacuumBreakTime.ToString()));

            this.TransferDataStream(CommunicationCommand.Write, CommunicationID.MainBoard, CommunicationAddress._9039_ParameterAll, sb.ToString());
        }

        public void FormChange(int index)
        {
            this.smartForm1.Show(index);
        }

        #region SystemConfiguration File
        private void CreateSystemConfigurationFile()
        {
            StructSystemConfigurationItem structItem;
            
            this.SystemConfig.Initialize();

            structItem.VacuumStartTime = this.SystemConfig.VacuumStartTime;
            structItem.VacuumHoldTime = this.SystemConfig.VacuumHoldTime;
            structItem.VacuumBreakTime = this.SystemConfig.VacuumBreakTime;
            structItem.Chart1DrawStep = this.SystemConfig.Chart1DrawStep;
            structItem.Chart2DrawStep = this.SystemConfig.Chart2DrawStep;
            structItem.OverRange = this.SystemConfig.OverRange;

            this.smartFileIO.StructType.Write(structItem, 0, SmartFile.WriteMode.Overwrite);
        }
        public void SaveSystemConfigurationFile(SystemConfiguration item)
        {
            string fullFilePath = "";
            bool fileCheck = false;
            StructSystemConfigurationItem structItem;

            fullFilePath = this.PathSystemFileFolder + "system.cfg";
            this.smartFileIO.FilePathName = fullFilePath;

            FileInfo fileInfo = new FileInfo(fullFilePath);
            fileCheck = fileInfo.Exists;

            if (fileCheck == true)
            {
                this.smartFileIO.Open();
                this.smartFileIO.StructType.SetStructType(typeof(StructSystemConfigurationItem));
            }
            else
            {
                this.smartFileIO.Open();
                this.smartFileIO.StructType.SetStructType(typeof(StructSystemConfigurationItem));

                this.CreateSystemConfigurationFile();
            }

            structItem.VacuumStartTime = item.VacuumStartTime;
            structItem.VacuumHoldTime = item.VacuumHoldTime;
            structItem.VacuumBreakTime = item.VacuumBreakTime;
            structItem.Chart1DrawStep = item.Chart1DrawStep;
            structItem.Chart2DrawStep = item.Chart2DrawStep;
            
            structItem.OverRange = item.OverRange;

            this.smartFileIO.StructType.Write(structItem, 0, SmartFile.WriteMode.Overwrite);
            this.smartFileIO.Close();
        }
        public void LoadSystemConfigurationFile()
        {
            string fullFilePath = "";
            bool fileCheck = false;
            StructSystemConfigurationItem structItem;

            fullFilePath = this.PathSystemFileFolder + "system.cfg";
            this.smartFileIO.FilePathName = fullFilePath;

            FileInfo fileInfo = new FileInfo(fullFilePath);
            fileCheck = fileInfo.Exists;

            if (fileCheck == true)
            {
                this.smartFileIO.Open();
                this.smartFileIO.StructType.SetStructType(typeof(StructSystemConfigurationItem));
            }
            else
            {
                this.smartFileIO.Open();
                this.smartFileIO.StructType.SetStructType(typeof(StructSystemConfigurationItem));

                this.CreateSystemConfigurationFile();
            }

            structItem = (StructSystemConfigurationItem)this.smartFileIO.StructType.Read(0);

            this.SystemConfig.VacuumStartTime = structItem.VacuumStartTime;
            this.SystemConfig.VacuumHoldTime = structItem.VacuumHoldTime;
            this.SystemConfig.VacuumBreakTime = structItem.VacuumBreakTime;
            this.SystemConfig.Chart1DrawStep = structItem.Chart1DrawStep;
            this.SystemConfig.Chart2DrawStep = structItem.Chart2DrawStep;

            this.SystemConfig.OverRange = structItem.OverRange;

            this.smartFileIO.Close();
        }
        #endregion

        #region Uart Communication
        private void OpenSmartUartLink()
        {
            string fullPath = "";

            try
            {
                if (this.smartSerialPortLink.IsOpen == false)
                    this.smartSerialPortLink.Open();
            }
            catch
            {
            }

            #region Test 용 통신 로그
            fullPath = this.PathDataBackupFolder + "Communicationlog.txt";
            this.smartFileCommunicationLog.FilePathName = fullPath;
            //this.smartFileCommunicationLog.Open();
            //this.IsCommunicationLogOpen = true;
            #endregion
        }
        public void CloseSmartUartLink()
        {
            this.smartSerialPortLink.Close();
        }

        private bool SizeCheck(string cmd, string strTemp)
        {
            bool ret = false;
            string dataSize = "";
            int size = 0;

            if (strTemp == null || strTemp.Length == 0)
            {
                ret = false;
                return ret;
            }

            try
            {
                if (cmd == "P")
                    dataSize = strTemp.Substring(14, strTemp.Length - 16);
                else // "S"
                    dataSize = strTemp.Substring(10, strTemp.Length - 12);

                size = int.Parse(strTemp.Substring(6, 4).Trim());
            }
            catch
            {
                ret = false;
                return ret;
            }

            if (dataSize.Length == size)
                ret = true;
            else
            {
                ret = false;
            }

            return ret;
        }
        private bool ChksumCheck(string strTemp)
        {
            bool ret = false;
            string chkSum = "", dataChksum = "";

            if (strTemp == null || strTemp.Length == 0)
                ret = false;
            else
            {
                chkSum = strTemp.Substring(strTemp.Length - 2, 2);
                dataChksum = this.Checksumcalculator(strTemp.Substring(0, strTemp.Length - 2));

                if (chkSum == dataChksum)
                    ret = true;
                else
                    ret = false;
            }

            return ret;
        }
        private string Checksumcalculator(string strTemp)
        {
            string chkSum = "";
            byte[] temp;
            int value = 0, first = 0, second = 0;
            char char1, char2;

            if (strTemp == null || strTemp.Length == 0)
                chkSum = "cc";
            else
            {
                temp = new UTF8Encoding().GetBytes(strTemp);

                for (int i = 0; i < temp.Length; i++)
                    value += temp[i];

                first = (value & 0x00f0) >> 4;
                if (first > 9)
                    char1 = (char)(first + 0x37);
                else
                    char1 = (char)(first + 0x30);

                second = value & 0x000f;
                if (second > 9)
                    char2 = (char)(second + 0x37);
                else
                    char2 = (char)(second + 0x30);

                chkSum = char1.ToString() + char2.ToString();
            }

            return chkSum;
        }
        private string Checksumcalculator(byte[] strTemp)
        {
            string chkSum = "";
            byte[] temp;
            int value = 0, first = 0, second = 0;
            char char1, char2;

            if (strTemp == null || strTemp.Length == 0)
                chkSum = "cc";
            else
            {
                temp = strTemp;

                for (int i = 0; i < temp.Length; i++)
                    value += temp[i];

                first = (value & 0x00f0) >> 4;
                if (first > 9)
                    char1 = (char)(first + 0x37);
                else
                    char1 = (char)(first + 0x30);

                second = value & 0x000f;
                if (second > 9)
                    char2 = (char)(second + 0x37);
                else
                    char2 = (char)(second + 0x30);

                chkSum = char1.ToString() + char2.ToString();
            }

            return chkSum;
        }

        public int TransferData(string command, string id)
        {
            int ret = 0;
            string chkSum = "cc";
            StringBuilder sb = new StringBuilder();

            sb.Append(command);
            sb.Append(id);

            chkSum = this.Checksumcalculator(sb.ToString());

            sb.Append(chkSum);

            if (this.smartSerialPortLink.IsOpen == true)
                this.smartSerialPortLink.WriteFrame(sb.ToString(), SmartSerialPort.CODETYPES.ASCIICODE);

            // 통신 확인 로그
            if (this.IsCommunicationLogOpen == true)
                this.smartFileCommunicationLog.StringType.Write(string.Format("Send ({0:yyyy-MM-dd HH:mm:ss}): {1}", DateTime.Now, sb.ToString()));

            return ret;
        }
        public int TransferDataStream(string command, string id, string address, string data)
        {
            int ret = 0;
            string chkSum = "cc";
            StringBuilder sb = new StringBuilder();

            sb.Append(command);
            sb.Append(id);
            sb.Append(Helper.StringZeroFillDigits4(data.Length.ToString()));
            sb.Append(address);
            sb.Append(data);

            chkSum = this.Checksumcalculator(sb.ToString());

            sb.Append(chkSum);

            if (this.smartSerialPortLink.IsOpen == true)
                this.smartSerialPortLink.WriteFrame(sb.ToString(), SmartSerialPort.CODETYPES.ASCIICODE);

            // 통신 확인 로그
            if (this.IsCommunicationLogOpen == true)
                this.smartFileCommunicationLog.StringType.Write(string.Format("Send ({0:yyyy-MM-dd HH:mm:ss}): {1}", DateTime.Now, sb.ToString()));

            return ret;
        }
        public int TransferDataStream4(string command, string id, string address, string data)
        {
            int ret = 0;
            string chkSum = "cc";
            StringBuilder sb = new StringBuilder();

            sb.Append(command);
            sb.Append(id);
            sb.Append(Helper.StringZeroFillDigits4("4"));
            sb.Append(address);
            sb.Append(Helper.StringZeroFillDigits4(data));

            chkSum = this.Checksumcalculator(sb.ToString());

            sb.Append(chkSum);

            if (this.smartSerialPortLink.IsOpen == true)
                this.smartSerialPortLink.WriteFrame(sb.ToString(), SmartSerialPort.CODETYPES.ASCIICODE);

            // 통신 확인 로그
            if (this.IsCommunicationLogOpen == true)
                this.smartFileCommunicationLog.StringType.Write(string.Format("Send ({0:yyyy-MM-dd HH:mm:ss}): {1}", DateTime.Now, sb.ToString()));

            return ret;
        }
        public int TransferDataStream6(string command, string id, string address, string data)
        {
            int ret = 0;
            string chkSum = "cc";
            StringBuilder sb = new StringBuilder();

            sb.Append(command);
            sb.Append(id);
            sb.Append(Helper.StringZeroFillDigits4("6"));
            sb.Append(address);
            sb.Append(Helper.StringZeroFillDigits6(data));

            chkSum = this.Checksumcalculator(sb.ToString());

            sb.Append(chkSum);

            if (this.smartSerialPortLink.IsOpen == true)
                this.smartSerialPortLink.WriteFrame(sb.ToString(), SmartSerialPort.CODETYPES.ASCIICODE);

            // 통신 확인 로그
            if (this.IsCommunicationLogOpen == true)
                this.smartFileCommunicationLog.StringType.Write(string.Format("Send ({0:yyyy-MM-dd HH:mm:ss}): {1}", DateTime.Now, sb.ToString()));

            return ret;
        }
        private void ReceiveData()
        {
            int ret = 0;
            string strTemp = "";
            byte[] readByte;

            SmartSerialPort.FRAMEDATAREADSTATUS receiveDataState = SmartSerialPort.FRAMEDATAREADSTATUS.EMPTY;

            try
            {
                receiveDataState = this.smartSerialPortLink.ReadQueue(out readByte);
                strTemp = Encoding.Default.GetString(readByte, 0, readByte.Length);
            }
            catch
            {
                return;
            }

            if ((receiveDataState == SmartSerialPort.FRAMEDATAREADSTATUS.EMPTY) || (receiveDataState == SmartSerialPort.FRAMEDATAREADSTATUS.FAILDATA))
            {
                return;
            }

            try
            {
                switch (strTemp[0])
                {
                    case 'C':
                        if ((ret = this.ReceiveCommandC(strTemp)) != 0)
                            return;
                        break;
                    case 'P':
                        if ((ret = this.ReceiveCommandP(strTemp)) != 0)
                            return;
                        break;
                    case 'S':
                        if ((ret = this.ReceiveCommandS(strTemp)) != 0)
                            return;
                        break;
                    default:
                        break;
                }
            }
            catch
            {
            }
        }

        private int ReceiveCommandC(string strTemp)
        {
            int ret = 0;
            string cmd = "", data = "";

            if (this.ChksumCheck(strTemp) == false)
            {
                // 로그
                if (this.IsCommunicationLogOpen == true)
                    this.smartFileCommunicationLog.StringType.Write(string.Format("Receive ({0:yyyy-MM-dd HH:mm:ss}): {1} : Receive Command Data CHKSUM Error", DateTime.Now, strTemp));
                return ret = -1;
            }

            // 로그
            if (this.IsCommunicationLogOpen == true)
                this.smartFileCommunicationLog.StringType.Write(string.Format("Receive ({0:yyyy-MM-dd HH:mm:ss}): {1}", DateTime.Now, strTemp));

            cmd = strTemp.Substring(0, 3);

            switch (cmd)
            {
                case "CI0":
                    this.EquipmentStatus = Define.E_EquipmentStatus.Stop;
                    this.ChildFormMainDisplay.UpdateEquipmentStatusDisplay(this.EquipmentStatus);

                    this.TransferSystemParameter();
                    break;
                case "CBS":
                    this.EquipmentStatus = DataStore.Define.E_EquipmentStatus.Start;

                    this.ChildFormMainDisplay.UpdateEquipmentStatusDisplay(this.EquipmentStatus);
                    break;
                case "CBT":
                    this.EquipmentStatus = Define.E_EquipmentStatus.Stop;

                    this.ChildFormMainDisplay.UpdateEquipmentStatusDisplay(this.EquipmentStatus);
                    break;
                default:
                    break;
            }

            return ret;
        }
        private int ReceiveCommandP(string strTemp)
        {
            int ret = 0;
            string cmd = "", address = "", lane = "", receiveData = "";

            // SIZE 확인
            if (this.SizeCheck("P", strTemp) == false)
            {
                // 로그
                if (this.IsCommunicationLogOpen == true)
                    this.smartFileCommunicationLog.StringType.Write(string.Format("Receive ({0:yyyy-MM-dd HH:mm:ss}): {1} : Receive Stream Data SIZE Error", DateTime.Now, strTemp));
                return ret = -1;
            }
            // CHKSUM 확인
            if (this.ChksumCheck(strTemp) == false)
            {
                // 로그
                if (this.IsCommunicationLogOpen == true)
                    this.smartFileCommunicationLog.StringType.Write(string.Format("Receive ({0:yyyy-MM-dd HH:mm:ss}): {1} : Receive Stream Data CHKSUM Error", DateTime.Now, strTemp));
                return ret = -1;
            }

            // 로그
            if (this.IsCommunicationLogOpen == true)
                this.smartFileCommunicationLog.StringType.Write(string.Format("Receive ({0:yyyy-MM-dd HH:mm:ss}): {1}", DateTime.Now, strTemp));

            cmd = strTemp.Substring(0, 3);
            lane = strTemp.Substring(5, 1);
            address = strTemp.Substring(10, 4);
            receiveData = strTemp.Substring(14, strTemp.Length - 16);

            switch (cmd)
            {
                case "PR0":
                    if ((ret = this.ReceiveCommandPR0(lane, address, receiveData)) != 0)
                        return ret = -1;
                    break;
                case "PW0":
                    if ((ret = this.ReceiveCommandPW0(lane, address, receiveData)) != 0)
                        return ret = -1;
                    break;
                default:
                    break;
            }

            return ret;
        }
        private int ReceiveCommandS(string strTemp)
        {
            int ret = 0;
            string cmd = "", lane = "", receiveData = "";

            // SIZE 확인
            if (this.SizeCheck("S", strTemp) == false)
            {
                // 로그
                if (this.IsCommunicationLogOpen == true)
                    this.smartFileCommunicationLog.StringType.Write(string.Format("Receive ({0:yyyy-MM-dd HH:mm:ss}): {1} : Receive Stream Data SIZE Error", DateTime.Now, strTemp));
                return ret = -1;
            }
            // CHKSUM 확인
            if (this.ChksumCheck(strTemp) == false)
            {
                // 로그
                if (this.IsCommunicationLogOpen == true)
                    this.smartFileCommunicationLog.StringType.Write(string.Format("Receive ({0:yyyy-MM-dd HH:mm:ss}): {1} : Receive Stream Data CHKSUM Error", DateTime.Now, strTemp));
                return ret = -1;
            }

            // 로그
            if (this.IsCommunicationLogOpen == true)
                this.smartFileCommunicationLog.StringType.Write(string.Format("Receive ({0:yyyy-MM-dd HH:mm:ss}): {1}", DateTime.Now, strTemp));

            cmd = strTemp.Substring(0, 3);
            lane = strTemp.Substring(5, 1);
            receiveData = strTemp.Substring(10, strTemp.Length - 12);

            switch (cmd)
            {
                case "SN0":
                    if ((ret = this.ReceiveCommandSN0(lane, receiveData)) != 0)
                        return ret;
                    break;
                case "SR0":
                    if ((ret = this.ReceiveCommandSR0(lane, receiveData)) != 0)
                        return ret;
                    break;
                case "ST0":
                    if ((ret = this.ReceiveCommandST0(lane, receiveData)) != 0)
                        return ret;
                    break;
                case "SA0":
                    if ((ret = this.ReceiveCommandSA0(lane, receiveData)) != 0)
                        return ret;
                    break;
                default:
                    break;
            }

            return ret;
        }

        // 파라미터 읽기 응답
        private int ReceiveCommandPR0(string lane, string address, string receiveData)
        {
            int ret = 0, iValue = 0;

            try
            {
                switch (address)
                {
                    default:
                        break;
                }
            }
            catch
            {
                ret = -1;
            }

            return ret;
        }
        // 파라미터 쓰기 응답
        private int ReceiveCommandPW0(string lane, string address, string receiveData)
        {
            int ret = 0;
            DataStore.Define.E_ResponseData response = DataStore.Define.E_ResponseData.NAK;

            try
            {
                switch (address)
                {
                    case "9039":
                        break;
                    default:
                        break;
                }
            }
            catch
            {
                ret = -1;
            }

            return ret;
        }

        // 노멀 데이터
        private int ReceiveCommandSN0(string lane, string receiveData)
        {
            int ret = 0;

            try
            {
                switch (lane)
                {
                    case "Z":
                        #region Value Assign
                        for (int i = 0; i < 10; i++)
                        {
                            this.CollectionLeakDatas[i].ProgressStatus = Helper.StringToProgressStatus(receiveData.Substring(i * 22, 2));
                            this.CollectionLeakDatas[i].CurrentValueSign = receiveData.Substring(i * 22 + 2, 1);
                            this.CollectionLeakDatas[i].CurrentValue = int.Parse(receiveData.Substring(i * 22 + 3, 5)).ToString();
                            this.CollectionLeakDatas[i].MaxValueSign = receiveData.Substring(i * 22 + 8, 1);
                            this.CollectionLeakDatas[i].MaxValue = int.Parse(receiveData.Substring(i * 22 + 9, 5)).ToString();
                            this.CollectionLeakDatas[i].StDev = receiveData.Substring(i * 22 + 14, 8);
                        }
                        #endregion
                        this.ChildFormMainDisplay.UpdateNomalLeakDataDisplay(this.CollectionLeakDatas);
                        break;
                    default:
                        break;
                }
            }
            catch
            {
                ret = -1;
            }

            return ret;
        }
        // 판정 데이터
        private int ReceiveCommandSR0(string lane, string receiveData)
        {
            int ret = 0;

            try
            {
                switch (lane)
                {
                    case "A":
                        #region Value Assign
                        this.CollectionLeakDatas[0].JudgmentStatus = Helper.StringToJudgmentStatus(receiveData.Substring(0, 2));
                        this.CollectionLeakDatas[0].ResultSD = receiveData.Substring(2, 8).Trim();
                        #endregion
                        this.ChildFormMainDisplay.UpdateStartLeakData1Display(this.CollectionLeakDatas[0]);
                        break;
                    case "B":
                        #region Value Assign
                        this.CollectionLeakDatas[1].JudgmentStatus = Helper.StringToJudgmentStatus(receiveData.Substring(0, 2));
                        this.CollectionLeakDatas[1].ResultSD = receiveData.Substring(2, 8).Trim();
                        #endregion
                        this.ChildFormMainDisplay.UpdateStartLeakData2Display(this.CollectionLeakDatas[1]);
                        break;
                    case "C":
                        #region Value Assign
                        this.CollectionLeakDatas[2].JudgmentStatus = Helper.StringToJudgmentStatus(receiveData.Substring(0, 2));
                        this.CollectionLeakDatas[2].ResultSD = receiveData.Substring(2, 8).Trim();
                        #endregion
                        this.ChildFormMainDisplay.UpdateStartLeakData3Display(this.CollectionLeakDatas[2]);
                        break;
                    case "D":
                        #region Value Assign
                        this.CollectionLeakDatas[3].JudgmentStatus = Helper.StringToJudgmentStatus(receiveData.Substring(0, 2));
                        this.CollectionLeakDatas[3].ResultSD = receiveData.Substring(2, 8).Trim();
                        #endregion
                        this.ChildFormMainDisplay.UpdateStartLeakData4Display(this.CollectionLeakDatas[3]);
                        break;
                    case "E":
                        #region Value Assign
                        this.CollectionLeakDatas[4].JudgmentStatus = Helper.StringToJudgmentStatus(receiveData.Substring(0, 2));
                        this.CollectionLeakDatas[4].ResultSD = receiveData.Substring(2, 8).Trim();
                        #endregion
                        this.ChildFormMainDisplay.UpdateStartLeakData5Display(this.CollectionLeakDatas[4]);
                        break;
                    case "F":
                        #region Value Assign
                        this.CollectionLeakDatas[5].JudgmentStatus = Helper.StringToJudgmentStatus(receiveData.Substring(0, 2));
                        this.CollectionLeakDatas[5].ResultSD = receiveData.Substring(2, 8).Trim();
                        #endregion
                        this.ChildFormMainDisplay.UpdateStartLeakData6Display(this.CollectionLeakDatas[5]);
                        break;
                    case "G":
                        #region Value Assign
                        this.CollectionLeakDatas[6].JudgmentStatus = Helper.StringToJudgmentStatus(receiveData.Substring(0, 2));
                        this.CollectionLeakDatas[6].ResultSD = receiveData.Substring(2, 8).Trim();
                        #endregion
                        this.ChildFormMainDisplay.UpdateStartLeakData7Display(this.CollectionLeakDatas[6]);
                        break;
                    case "H":
                        #region Value Assign
                        this.CollectionLeakDatas[7].JudgmentStatus = Helper.StringToJudgmentStatus(receiveData.Substring(0, 2));
                        this.CollectionLeakDatas[7].ResultSD = receiveData.Substring(2, 8).Trim();
                        #endregion
                        this.ChildFormMainDisplay.UpdateStartLeakData8Display(this.CollectionLeakDatas[7]);
                        break;
                    case "I":
                        #region Value Assign
                        this.CollectionLeakDatas[8].JudgmentStatus = Helper.StringToJudgmentStatus(receiveData.Substring(0, 2));
                        this.CollectionLeakDatas[8].ResultSD = receiveData.Substring(2, 8).Trim();
                        #endregion
                        this.ChildFormMainDisplay.UpdateStartLeakData9Display(this.CollectionLeakDatas[8]);
                        break;
                    case "J":
                        #region Value Assign
                        this.CollectionLeakDatas[9].JudgmentStatus = Helper.StringToJudgmentStatus(receiveData.Substring(0, 2));
                        this.CollectionLeakDatas[9].ResultSD = receiveData.Substring(2, 8).Trim();
                        #endregion
                        this.ChildFormMainDisplay.UpdateStartLeakData10Display(this.CollectionLeakDatas[9]);
                        break;
                    case "Z":
                        #region Value Assign
                        for (int i = 0; i < 10; i++)
                        {
                            this.CollectionLeakDatas[i].JudgmentStatus = Helper.StringToJudgmentStatus(receiveData.Substring(i * 10, 2));
                            this.CollectionLeakDatas[i].ResultSD = receiveData.Substring(i * 10 + 2, 8).Trim();
                        }
                        #endregion
                        this.ChildFormMainDisplay.UpdateStartLeakDataDisplay(this.CollectionLeakDatas);
                        break;
                    default:
                        break;
                }
            }
            catch
            {
                ret = -1;
            }

            return ret;
        }
        // IO테스트-IN
        private int ReceiveCommandST0(string lane, string receiveData)
        {
            int ret = 0;

            switch (lane)
            {
                case "0":
                    #region Value Assign
                    //for (int i = 0; i < 15; i++)
                    //    this.CollectionIOTest_InputData[i] = receiveData.Substring(i, 1);
                    #endregion
                    //if (this.SystemConfig.CurrentForm == DataStore.FormStore.FormIOTest)
                    //    this.ChildFormIOTest.UpdateInputRead(this.CollectionIOTest_InputData);
                    break;
                default:
                    break;
            }

            return ret;
        }
        // 알람
        private int ReceiveCommandSA0(string lane, string receiveData)
        {
            int ret = 0;

            switch (lane)
            {
                case "0":
                    #region Value Assign
                    //this.CurrentAlarmList.SetAlarm(receiveData.Substring(0, 8));
                    #endregion

                    //this.ChildFormMainDisplay.UpdateDisplayAlarmView(this.CurrentAlarmList);
                    break;
                default:
                    break;
            }

            return ret;
        }
        #endregion

        #endregion

        #region Override Member
        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            // 변수 초기 셋팅
            this.DefaultSetting();
            // SystemConfiguration 파일 읽기
            this.LoadSystemConfigurationFile();

            // Form 생성
            this.CreateForm();

            // 통신 OPEN
            this.OpenSmartUartLink();

            this.smartForm1.Show(1);

            // 초기 파라미터 전송
            this.TransferSystemParameter();

            // 화면 시계 표시 타이머
            this.timer.Enabled = true;
        }
        #endregion

        #region Event Handler
        private void smartSerialPortLink_OnReadQueueEvent()
        {
            this.ReceiveData();

            // 통신 확인
            if (this.CommunicationCheckCount / 3 == 1)
            {
                if (this.ChildFormMainDisplay != null)
                    this.ChildFormMainDisplay.labelCommunicationStatus.Visible = true;

                this.CommunicationCheckCount = 0;
            }
            else
            {
                if (this.ChildFormMainDisplay != null)
                    this.ChildFormMainDisplay.labelCommunicationStatus.Visible = false;

                this.CommunicationCheckCount += 1;
            }
        }

        private void smartButton1_Click(object sender, EventArgs e)
        {
            this.smartForm1.Show(2);
        }
        private void smartButton2_Click(object sender, EventArgs e)
        {
            this.smartForm1.Show(1);
        }

        private void timer_Tick(object sender, EventArgs e)
        {
            this.ChildFormMainDisplay.UpdateDisplayTime();
        }
        #endregion
    }
}