﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using INT_PT002.Controls;
using INT_PT002.DataStore;

namespace INT_PT002.Forms
{
    public partial class FormMenu : Form
    {
        #region Field
        private FormMain m_ParentForm;

        ControlMenuManualIoTest Child_Manual_IoTest;
        ControlMenuManualMotorSetting Child_Manual_MotorSetting;
        ControlMenuSettingCommunication Child_Setting_Communication;
        ControlMenuSettingConfiguration Child_Setting_Configuration;
        ControlMenuSettingUserEditor Child_Setting_UserEditor;

        private Define.E_TopMenuStore SelectedTopMenu;
        #endregion

        #region Constructor
        public FormMenu(FormMain parent)
        {
            InitializeComponent();

            this.ParentForm = parent;
            this.Initialize();
            this.CreateChildControls();
        } 
        #endregion

        #region Property
        public FormMain ParentForm
        {
            get { return this.m_ParentForm; }
            private set { this.m_ParentForm = value; }
        }
        #endregion

        #region Method
        private void Initialize()
        {
            this.SelectedTopMenu = Define.E_TopMenuStore.Recipe;
        }
        private void CreateChildControls()
        {
            this.Child_Manual_IoTest = new ControlMenuManualIoTest(this);
            this.Child_Manual_MotorSetting = new ControlMenuManualMotorSetting(this);
            this.Child_Setting_Communication = new ControlMenuSettingCommunication(this);
            this.Child_Setting_Configuration = new ControlMenuSettingConfiguration(this);
            this.Child_Setting_UserEditor = new ControlMenuSettingUserEditor(this);

            this.Controls.Add(this.Child_Manual_IoTest);
            this.Controls.Add(this.Child_Manual_MotorSetting);
            this.Controls.Add(this.Child_Setting_Communication);
            this.Controls.Add(this.Child_Setting_Configuration);
            this.Controls.Add(this.Child_Setting_UserEditor);

            this.Child_Manual_IoTest.Location = new Point(0, 0);
            this.Child_Manual_MotorSetting.Location = new Point(0, 0);
            this.Child_Setting_Communication.Location = new Point(0, 0);
            this.Child_Setting_Configuration.Location = new Point(0, 0);
            this.Child_Setting_UserEditor.Location = new Point(0, 0);
        }

        private void SetTopMenu(Define.E_TopMenuStore bottom)
        {
            switch (bottom)
            {
                case Define.E_TopMenuStore.Recipe:
                    this.buttonRecipe.ButtonDown();
                    this.buttonSetting.ButtonUp();
                    this.buttonManual.ButtonUp();
                    this.buttonLog.ButtonUp();
                    this.buttonSystem.ButtonUp();

                    this.buttonBottom1.Visible = false;
                    this.buttonBottom2.Visible = false;
                    this.buttonBottom3.Visible = false;
                    this.buttonBottom4.Visible = false;
                    this.buttonBottom5.Visible = false;
                    this.buttonBottom6.Visible = false;
                    break;
                case Define.E_TopMenuStore.Setting:
                    this.buttonRecipe.ButtonUp();
                    this.buttonSetting.ButtonDown();
                    this.buttonManual.ButtonUp();
                    this.buttonLog.ButtonUp();
                    this.buttonSystem.ButtonUp();

                    this.buttonBottom1.ButtonText = "Config";
                    this.buttonBottom2.ButtonText = "COM";
                    this.buttonBottom3.ButtonText = "User";

                    this.buttonBottom1.Visible = true;
                    this.buttonBottom2.Visible = true;
                    this.buttonBottom3.Visible = true;
                    this.buttonBottom4.Visible = false;
                    this.buttonBottom5.Visible = false;
                    this.buttonBottom6.Visible = false;
                    break;
                case Define.E_TopMenuStore.Manual:
                    this.buttonRecipe.ButtonUp();
                    this.buttonSetting.ButtonUp();
                    this.buttonManual.ButtonDown();
                    this.buttonLog.ButtonUp();
                    this.buttonSystem.ButtonUp();

                    this.buttonBottom1.ButtonText = "IO Test";
                    this.buttonBottom2.ButtonText = "Motor";

                    this.buttonBottom1.Visible = true;
                    this.buttonBottom2.Visible = true;
                    this.buttonBottom3.Visible = false;
                    this.buttonBottom4.Visible = false;
                    this.buttonBottom5.Visible = false;
                    this.buttonBottom6.Visible = false;
                    break;
                case Define.E_TopMenuStore.Log:
                    this.buttonRecipe.ButtonUp();
                    this.buttonSetting.ButtonUp();
                    this.buttonManual.ButtonUp();
                    this.buttonLog.ButtonDown();
                    this.buttonSystem.ButtonUp();

                    this.buttonBottom1.ButtonText = "History";
                    this.buttonBottom2.ButtonText = "Inspection";
                    this.buttonBottom3.ButtonText = "Alarm";

                    this.buttonBottom1.Visible = true;
                    this.buttonBottom2.Visible = true;
                    this.buttonBottom3.Visible = true;
                    this.buttonBottom4.Visible = false;
                    this.buttonBottom5.Visible = false;
                    this.buttonBottom6.Visible = false;
                    break;
                case Define.E_TopMenuStore.System:
                    this.buttonRecipe.ButtonUp();
                    this.buttonSetting.ButtonUp();
                    this.buttonManual.ButtonUp();
                    this.buttonLog.ButtonUp();
                    this.buttonSystem.ButtonDown();

                    this.buttonBottom1.ButtonText = "Information";
                    this.buttonBottom2.ButtonText = "Time";
                    this.buttonBottom3.ButtonText = "Equipment";
                    this.buttonBottom4.ButtonText = "Update";

                    this.buttonBottom1.Visible = true;
                    this.buttonBottom2.Visible = true;
                    this.buttonBottom3.Visible = true;
                    this.buttonBottom4.Visible = true;
                    this.buttonBottom5.Visible = false;
                    this.buttonBottom6.Visible = false;
                    break;
                default:
                    this.buttonBottom1.Visible = false;
                    this.buttonBottom2.Visible = false;
                    this.buttonBottom3.Visible = false;
                    this.buttonBottom4.Visible = false;
                    this.buttonBottom5.Visible = false;
                    this.buttonBottom6.Visible = false;
                    break;
            }
        }
        private void SetBottomMenuRecipe(Define.E_MenuRecipeStore menu)
        { 
        }
        private void SetBottomMenuSetting(Define.E_MenuSettingStore menu)
        {
            switch (menu)
            {
                case Define.E_MenuSettingStore.Communication:
                    break;
                case Define.E_MenuSettingStore.Configuration:
                    break;
                case Define.E_MenuSettingStore.UserEditor:
                    break;
                default:
                    break;
            }
        }
        private void SetBottomMenuManual(Define.E_MenuManualStore menu)
        {
            switch (menu)
            {
                case Define.E_MenuManualStore.IoTest:
                    break;
                case Define.E_MenuManualStore.MotorSetting:
                    break;
                default:
                    break;
            }
        }
        private void SetBottomMenuLog(Define.E_MenuLogStore menu)
        {
            switch (menu)
            {
                case Define.E_MenuLogStore.History:
                    break;
                case Define.E_MenuLogStore.Inspection:
                    break;
                case Define.E_MenuLogStore.Alarm:
                    break;
                default:
                    break;
            }
        }
        private void SetBottomMenuSystem(Define.E_MenuSystemStore menu)
        {
            switch (menu)
            {
                case Define.E_MenuSystemStore.Information:
                    break;
                case Define.E_MenuSystemStore.Time:
                    break;
                case Define.E_MenuSystemStore.Equipment:
                    break;
                case Define.E_MenuSystemStore.Update:
                    break;
                default:
                    break;
            }
        }

        public void DisplayRefresh()
        {
            this.SelectedTopMenu = Define.E_TopMenuStore.Recipe;
            this.SetTopMenu(this.SelectedTopMenu);
        }
        #endregion

        #region Event Handler
        private void buttonHome_Click(object sender, EventArgs e)
        {
            this.ParentForm.ChildFormMainDisplay.DisplayRefresh();
            this.ParentForm.FormChange((int)Define.E_FormStore.FormMainDisplay);
        }
        private void buttonRecipe_Click(object sender, EventArgs e)
        {
            if (this.SelectedTopMenu != Define.E_TopMenuStore.Recipe)
            {
                this.SelectedTopMenu = Define.E_TopMenuStore.Recipe;
                this.SetTopMenu(this.SelectedTopMenu);
            }
        }
        private void buttonSetting_Click(object sender, EventArgs e)
        {
            if (this.SelectedTopMenu != Define.E_TopMenuStore.Setting)
            {
                this.SelectedTopMenu = Define.E_TopMenuStore.Setting;
                this.SetTopMenu(this.SelectedTopMenu);
            }
        }
        private void buttonManual_Click(object sender, EventArgs e)
        {
            if (this.SelectedTopMenu != Define.E_TopMenuStore.Manual)
            {
                this.SelectedTopMenu = Define.E_TopMenuStore.Manual;
                this.SetTopMenu(this.SelectedTopMenu);
            }
        }
        private void buttonLog_Click(object sender, EventArgs e)
        {
            if (this.SelectedTopMenu != Define.E_TopMenuStore.Log)
            {
                this.SelectedTopMenu = Define.E_TopMenuStore.Log;
                this.SetTopMenu(this.SelectedTopMenu);
            }
        }
        private void buttonSystem_Click(object sender, EventArgs e)
        {
            if (this.SelectedTopMenu != Define.E_TopMenuStore.System)
            {
                this.SelectedTopMenu = Define.E_TopMenuStore.System;
                this.SetTopMenu(this.SelectedTopMenu);
            }
        }
        #endregion

        private void buttonBottom1_Click(object sender, EventArgs e)
        {

        }

        private void buttonBottom2_Click(object sender, EventArgs e)
        {

        }

        private void buttonBottom3_Click(object sender, EventArgs e)
        {

        }

        private void buttonBottom4_Click(object sender, EventArgs e)
        {

        }

        private void buttonBottom5_Click(object sender, EventArgs e)
        {

        }

        private void buttonBottom6_Click(object sender, EventArgs e)
        {

        }
    }
}